summaryrefslogtreecommitdiffstats
path: root/tools/lib/h5diff.c
diff options
context:
space:
mode:
Diffstat (limited to 'tools/lib/h5diff.c')
-rw-r--r--tools/lib/h5diff.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/lib/h5diff.c b/tools/lib/h5diff.c
index 5f18ab3..c3d74b5 100644
--- a/tools/lib/h5diff.c
+++ b/tools/lib/h5diff.c
@@ -209,10 +209,10 @@ static int is_valid_options(diff_opt_t *options)
}
/* -------------------------------------------------------
* only allow --no-dangling-links along with --follow-links */
if(options->no_dangle_links && !options->follow_links)
{
- parallel_print("Error: --no-dangling-links must be used along with --follow-links option.\n");
+ parallel_print("Error: --no-dangling-links must be used along with --follow-symlinks option.\n");
options->err_stat=1;
ret = 0;
goto out;
@@ -209,10 +209,10 @@ static int is_valid_options(diff_opt_t *options)
}
/* -------------------------------------------------------
- * only allow --no-dangling-links along with --follow-links */
+ * only allow --no-dangling-links along with --follow-symlinks */
if(options->no_dangle_links && !options->follow_links)
{